@@ -11,17 +11,16 @@
 import os
 import shutil
 
-from typing import IO, List, Optional, Tuple
+from typing import Dict, IO, List, Optional, Tuple
 
-from flowserv.model.files.base import FileStore, FileObject
+from flowserv.config import FLOWSERV_BASEDIR
+from flowserv.model.files.base import FileStore, IOHandle
 
-import flowserv.config.api as config
-import flowserv.config.files as fconfig
 import flowserv.error as err
 import flowserv.util as util
 
 
-class FSFile(FileObject):
+class FSFile(IOHandle):
     """Implementation of the file object interface for files that are stored on
     the file system.
     """
@@ -75,34 +74,24 @@ class FileSystemStore(FileStore):
     all files are maintained on the local file system under a given base
     directory.
     """
-    def __init__(self, basedir: str = None):
+    def __init__(self, env: Dict):
         """Initialize the base directory. The directory is created if it does
         not exist.
 
         Parameters
         ----------
-        basedir: string, default=None
-            Path to the base directory.
+        env: dict
+            Configuration object that provides access to configuration
+            parameters in the environment.
         """
-        self.basedir = basedir if basedir is not None else config.API_BASEDIR()
+        self.basedir = env.get(FLOWSERV_BASEDIR)
+        if self.basedir is None:
+            raise err.MissingConfigurationError('API base directory')
 
     def __repr__(self):
         """Get object representation ."""
         return "<FileSystemStore dir='{}' />".format(self.basedir)
 
-    def configuration(self) -> List[Tuple[str, str]]:
-        """Get a list of tuples with the names of additional configuration
-        variables and their current values.
-
-        Returns
-        -------
-        list((string, string))
-        """
-        return [
-            (fconfig.FLOWSERV_FILESTORE_CLASS, 'FileSystemStore'),
-            (fconfig.FLOWSERV_FILESTORE_MODULE, 'flowserv.model.files.fs')
-        ]
-
     def copy_folder(self, key: str, dst: str):
         """Copy all files in the folder with the given key to a target folder.
         Creates the destination folder if it does not exist.
@@ -168,7 +157,7 @@ class FileSystemStore(FileStore):
         """
         return FSFile(os.path.join(self.basedir, key))
 
-    def store_files(self, files: List[Tuple[FileObject, str]], dst: str):
+    def store_files(self, files: List[Tuple[IOHandle, str]], dst: str):
         """Store a given list of file objects in the file store. The file
         destination key is a relative path name. This is used as the base path
         for all files. The file list contains tuples of file object and target
@@ -176,7 +165,7 @@ class FileSystemStore(FileStore):
 
         Paramaters
         ----------
-        file: flowserv.model.files.base.FileObject
+        file: flowserv.model.files.base.IOHandle
             The input file object.
         dst: string
             Relative target path for the stored file.
