@@ -367,7 +367,7 @@ class Numeric(Parameter):
             dtype=doc[pd.TYPE],
             name=doc[pd.NAME],
             index=doc[pd.INDEX],
-            label=doc[pd.LABEL],
+            label=doc.get(pd.LABEL),
             help=doc.get(pd.HELP),
             default=doc.get(pd.DEFAULT),
             required=doc[pd.REQUIRED],
