@@ -10,7 +10,7 @@
 
 import os
 
-from flowserv.model.parameter.files import FileParameter
+from flowserv.model.parameter.files import File
 from flowserv.model.template.parameter import ParameterIndex
 
 
@@ -30,11 +30,10 @@ LABEL_FILES = 'files'
 only the declaration for the runs folder.
 """
 PARA_RUNS = 'runs'
-PARAMETER = FileParameter(
-    para_id=PARA_RUNS,
+PARAMETER = File(
     name=PARA_RUNS,
     index=0,
     target=os.path.join(RUNS_DIR, RUNS_FILE)
 )
 PARAMETERS = ParameterIndex()
-PARAMETERS[PARAMETER.para_id] = PARAMETER
+PARAMETERS[PARAMETER.name] = PARAMETER
